===============================
plone.app.caching documentation
===============================

.. plone.app.caching documentation master file, created by
   sphinx-quickstart on Tue May 20 16:53:52 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: README.rst

Documentation
=============

Contents:

.. toctree::
   :maxdepth: 2

   caching-control-panel
   caching-profiles
   rulesets-and-caching-operations
   caching-proxies
   ram-cache
   etags
   composite-views
   split-views


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

